@@ -6,6 +6,7 @@ from .binning import MulticlassOptimalBinning
 from .binning import OptimalBinning
 from .binning.distributed import BinningProcessSketch
 from .binning.distributed import OptimalBinningSketch
+from .binning.multidimensional import ContinuousOptimalBinning2D
 from .binning.multidimensional import OptimalBinning2D
 from .binning.piecewise import ContinuousOptimalPWBinning
 from .binning.piecewise import OptimalPWBinning
@@ -17,6 +18,7 @@ __all__ = ['__version__',
            'BinningProcess',
            'BinningProcessSketch',
            'ContinuousOptimalBinning',
+           'ContinuousOptimalBinning2D',
            'ContinuousOptimalPWBinning',
            'MDLP',
            'MulticlassOptimalBinning',
